Llsd

Enum Llsd 

pub enum Llsd {
    Undefined,
    Boolean(bool),
    Integer(i32),
    Real(f64),
    String(String),
    Uri(Uri),
    Uuid(Uuid),
    Date(DateTime<Utc>),
    Binary(Vec<u8>),
    Array(Vec<Llsd>),
    Map(HashMap<String, Llsd>),
}

Variants



Undefined



Boolean(bool)



Integer(i32)



Real(f64)



String(String)



Uri(Uri)



Uuid(Uuid)



Date(DateTime<Utc>)



Binary(Vec<u8>)



Array(Vec<Llsd>)



Map(HashMap<String, Llsd>)

Implementations

Source

impl Llsd

pub fn is_undefined(&self) -> bool

Returns true if this is a Llsd::Undefined, otherwise false

pub fn is_boolean(&self) -> bool

Returns true if this is a Llsd::Boolean, otherwise false

pub fn as_boolean_mut(&mut self) -> Option<&mut bool>

Optionally returns mutable references to the inner fields if this is a Llsd::Boolean, otherwise None

pub fn as_boolean(&self) -> Option<&bool>

Optionally returns references to the inner fields if this is a Llsd::Boolean, otherwise None

pub fn into_boolean(self) -> Result<bool, Self>

Returns the inner fields if this is a Llsd::Boolean, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_boolean_unchecked(self) -> bool

Unchecked return of the inner fields of Llsd::Boolean.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_boolean_unchecked(&self) -> &bool

Unchecked reference of the inner fields of Llsd::Boolean.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_boolean_mut_unchecked(&mut self) -> &mut bool

Unchecked mutable reference of the inner fields of Llsd::Boolean.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_integer(&self) -> bool

Returns true if this is a Llsd::Integer, otherwise false

pub fn as_integer_mut(&mut self) -> Option<&mut i32>

Optionally returns mutable references to the inner fields if this is a Llsd::Integer, otherwise None

pub fn as_integer(&self) -> Option<&i32>

Optionally returns references to the inner fields if this is a Llsd::Integer, otherwise None

pub fn into_integer(self) -> Result<i32, Self>

Returns the inner fields if this is a Llsd::Integer, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_integer_unchecked(self) -> i32

Unchecked return of the inner fields of Llsd::Integer.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_integer_unchecked(&self) -> &i32

Unchecked reference of the inner fields of Llsd::Integer.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_integer_mut_unchecked(&mut self) -> &mut i32

Unchecked mutable reference of the inner fields of Llsd::Integer.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_real(&self) -> bool

Returns true if this is a Llsd::Real, otherwise false

pub fn as_real_mut(&mut self) -> Option<&mut f64>

Optionally returns mutable references to the inner fields if this is a Llsd::Real, otherwise None

pub fn as_real(&self) -> Option<&f64>

Optionally returns references to the inner fields if this is a Llsd::Real, otherwise None

pub fn into_real(self) -> Result<f64, Self>

Returns the inner fields if this is a Llsd::Real, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_real_unchecked(self) -> f64

Unchecked return of the inner fields of Llsd::Real.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_real_unchecked(&self) -> &f64

Unchecked reference of the inner fields of Llsd::Real.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_real_mut_unchecked(&mut self) -> &mut f64

Unchecked mutable reference of the inner fields of Llsd::Real.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_string(&self) -> bool

Returns true if this is a Llsd::String, otherwise false

pub fn as_string_mut(&mut self) -> Option<&mut String>

Optionally returns mutable references to the inner fields if this is a Llsd::String, otherwise None

pub fn as_string(&self) -> Option<&String>

Optionally returns references to the inner fields if this is a Llsd::String, otherwise None

pub fn into_string(self) -> Result<String, Self>

Returns the inner fields if this is a Llsd::String, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_string_unchecked(self) -> String

Unchecked return of the inner fields of Llsd::String.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_string_unchecked(&self) -> &String

Unchecked reference of the inner fields of Llsd::String.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_string_mut_unchecked(&mut self) -> &mut String

Unchecked mutable reference of the inner fields of Llsd::String.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_uri(&self) -> bool

Returns true if this is a Llsd::Uri, otherwise false

pub fn as_uri_mut(&mut self) -> Option<&mut Uri>

Optionally returns mutable references to the inner fields if this is a Llsd::Uri, otherwise None

pub fn as_uri(&self) -> Option<&Uri>

Optionally returns references to the inner fields if this is a Llsd::Uri, otherwise None

pub fn into_uri(self) -> Result<Uri, Self>

Returns the inner fields if this is a Llsd::Uri, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_uri_unchecked(self) -> Uri

Unchecked return of the inner fields of Llsd::Uri.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_uri_unchecked(&self) -> &Uri

Unchecked reference of the inner fields of Llsd::Uri.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_uri_mut_unchecked(&mut self) -> &mut Uri

Unchecked mutable reference of the inner fields of Llsd::Uri.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_uuid(&self) -> bool

Returns true if this is a Llsd::Uuid, otherwise false

pub fn as_uuid_mut(&mut self) -> Option<&mut Uuid>

Optionally returns mutable references to the inner fields if this is a Llsd::Uuid, otherwise None

pub fn as_uuid(&self) -> Option<&Uuid>

Optionally returns references to the inner fields if this is a Llsd::Uuid, otherwise None

pub fn into_uuid(self) -> Result<Uuid, Self>

Returns the inner fields if this is a Llsd::Uuid, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_uuid_unchecked(self) -> Uuid

Unchecked return of the inner fields of Llsd::Uuid.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_uuid_unchecked(&self) -> &Uuid

Unchecked reference of the inner fields of Llsd::Uuid.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_uuid_mut_unchecked(&mut self) -> &mut Uuid

Unchecked mutable reference of the inner fields of Llsd::Uuid.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_date(&self) -> bool

Returns true if this is a Llsd::Date, otherwise false

pub fn as_date_mut(&mut self) -> Option<&mut DateTime<Utc>>

Optionally returns mutable references to the inner fields if this is a Llsd::Date, otherwise None

pub fn as_date(&self) -> Option<&DateTime<Utc>>

Optionally returns references to the inner fields if this is a Llsd::Date, otherwise None

pub fn into_date(self) -> Result<DateTime<Utc>, Self>

Returns the inner fields if this is a Llsd::Date, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_date_unchecked(self) -> DateTime<Utc>

Unchecked return of the inner fields of Llsd::Date.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_date_unchecked(&self) -> &DateTime<Utc>

Unchecked reference of the inner fields of Llsd::Date.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_date_mut_unchecked(&mut self) -> &mut DateTime<Utc>

Unchecked mutable reference of the inner fields of Llsd::Date.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_binary(&self) -> bool

Returns true if this is a Llsd::Binary, otherwise false

pub fn as_binary_mut(&mut self) -> Option<&mut Vec<u8>>

Optionally returns mutable references to the inner fields if this is a Llsd::Binary, otherwise None

pub fn as_binary(&self) -> Option<&Vec<u8>>

Optionally returns references to the inner fields if this is a Llsd::Binary, otherwise None

pub fn into_binary(self) -> Result<Vec<u8>, Self>

Returns the inner fields if this is a Llsd::Binary, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_binary_unchecked(self) -> Vec<u8>

Unchecked return of the inner fields of Llsd::Binary.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_binary_unchecked(&self) -> &Vec<u8>

Unchecked reference of the inner fields of Llsd::Binary.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_binary_mut_unchecked(&mut self) -> &mut Vec<u8>

Unchecked mutable reference of the inner fields of Llsd::Binary.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_array(&self) -> bool

Returns true if this is a Llsd::Array, otherwise false

pub fn as_array_mut(&mut self) -> Option<&mut Vec<Llsd>>

Optionally returns mutable references to the inner fields if this is a Llsd::Array, otherwise None

pub fn as_array(&self) -> Option<&Vec<Llsd>>

Optionally returns references to the inner fields if this is a Llsd::Array, otherwise None

pub fn into_array(self) -> Result<Vec<Llsd>, Self>

Returns the inner fields if this is a Llsd::Array, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_array_unchecked(self) -> Vec<Llsd>

Unchecked return of the inner fields of Llsd::Array.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_array_unchecked(&self) -> &Vec<Llsd>

Unchecked reference of the inner fields of Llsd::Array.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_array_mut_unchecked(&mut self) -> &mut Vec<Llsd>

Unchecked mutable reference of the inner fields of Llsd::Array.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_map(&self) -> bool

Returns true if this is a Llsd::Map, otherwise false

pub fn as_map_mut(&mut self) -> Option<&mut HashMap<String, Llsd>>

Optionally returns mutable references to the inner fields if this is a Llsd::Map, otherwise None

pub fn as_map(&self) -> Option<&HashMap<String, Llsd>>

Optionally returns references to the inner fields if this is a Llsd::Map, otherwise None

pub fn into_map(self) -> Result<HashMap<String, Llsd>, Self>

Returns the inner fields if this is a Llsd::Map, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_map_unchecked(self) -> HashMap<String, Llsd>

Unchecked return of the inner fields of Llsd::Map.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_map_unchecked(&self) -> &HashMap<String, Llsd>

Unchecked reference of the inner fields of Llsd::Map.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_map_mut_unchecked(&mut self) -> &mut HashMap<String, Llsd>

Unchecked mutable reference of the inner fields of Llsd::Map.

Safety

Results in undefined behavior when it is the incorrect variant.

Source

impl Llsd

pub fn new() -> Self

pub fn array() -> Self

pub fn map() -> Self

pub fn clear(&mut self)

pub fn push<T: Into<Llsd>>(self, llsd: T) -> Result<Self>

pub fn insert<K: Into<String>, T: Into<Llsd>>( self, key: K, llsd: T, ) -> Result<Self>

pub fn get(&self, index: impl Index) -> Option<&Llsd>

pub fn get_mut(&mut self, index: impl Index) -> Option<&mut Llsd>

pub fn contains(&self, index: impl Index) -> bool

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn pointer(&self, pointer: &str) -> Option<&Llsd>

pub fn pointer_mut(&mut self, pointer: &str) -> Option<&mut Llsd>

pub fn take(&mut self) -> Self